@@ -2,6 +2,7 @@
 #' @author Victor Teh
 #' @family legacy
 #' @rdname defunct
+#' @param ... obsolete arguments
 DataStringBinary <- function(...) { #nolint: object_name_linter.
-  .Defunct("qr_code")
+  .Defunct("qr_code") # nocov
 }
