@@ -3,5 +3,5 @@
 #' @family legacy
 #' @rdname defunct
 ECgenerator <- function(...) { #nolint: object_name_linter.
-  .Defunct("qr_code")
+  .Defunct("qr_code") # nocov
 }
