@@ -4,5 +4,5 @@
 #' @rdname defunct
 
 qrFillUpMatrix <- function(...) { # nolint: object_name_linter.
-  .Defunct("qr_code")
+  .Defunct("qr_code") # nocov
 }
